@@ -3,22 +3,19 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "account.h"
-#include "accountconfig.h"
-#include "accountmanager.h"
-#include "network/networkcontroller.h"
+
+#include "networkcontroller.h"
 #include "notificationhandler.h"
-#include "preferences.h"
-#include "tokodon_debug.h"
 #include "tokodon_http_debug.h"
-#include "utils/utils.h"
-#include <QFileInfo>
-#include <QNetworkAccessManager>
-#include <qt6keychain/keychain.h>
+#include "utils.h"
 
 #ifdef HAVE_KUNIFIEDPUSH
-#include "utils/ecdh.h"
+#include "ecdh.h"
+#include "tokodon_debug.h"
 #endif
 
+#include <qt6keychain/keychain.h>
+
 using namespace Qt::Literals::StringLiterals;
 
 Account::Account(const QString &instanceUri, QNetworkAccessManager *nam, bool ignoreSslErrors, bool admin, QObject *parent)
@@ -188,7 +185,7 @@ void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply
     connect(reply, &QNetworkReply::finished, [reply, reply_cb, errorCallback]() {
         reply->deleteLater();
         if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) && !reply->url().toString().contains("nodeinfo"_L1)) {
-            qCWarning(TOKODON_LOG) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
+            qCWarning(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
             if (errorCallback) {
                 errorCallback(reply);
             } else {
@@ -278,7 +275,7 @@ QWebSocket *Account::streamingSocket(const QString &stream)
     return socket;
 }
 
-void Account::validateToken()
+void Account::validateToken(bool newAccount)
 {
     const QUrl verify_credentials = apiUrl(QStringLiteral("/api/v1/accounts/verify_credentials"));
 
@@ -307,15 +304,35 @@ void Account::validateToken()
             Q_EMIT identityChanged();
             Q_EMIT authenticated(true, {});
 
+#ifdef HAVE_KUNIFIEDPUSH
+            if (newAccount) {
+                // We asked for the push scope, so we can safely start subscribing to notifications
+                config()->setEnablePushNotifications(true);
+                config()->save();
+            }
+#endif
+
 #ifdef HAVE_KUNIFIEDPUSH
             get(
                 apiUrl(QStringLiteral("/api/v1/push/subscription")),
                 true,
                 this,
                 [=](QNetworkReply *reply) {
-                    Q_UNUSED(reply);
                     m_hasPushSubscription = true;
-                    updatePushNotifications();
+
+                    const QJsonDocument doc = QJsonDocument::fromJson(reply->readAll());
+
+                    if (!NetworkController::instance().endpoint.isEmpty() && doc["endpoint"_L1] != NetworkController::instance().endpoint) {
+                        qWarning(TOKODON_LOG) << "KUnifiedPush endpoint has changed to" << NetworkController::instance().endpoint << ", resubscribing!";
+
+                        deleteResource(apiUrl(QStringLiteral("/api/v1/push/subscription")), true, this, [=](QNetworkReply *reply) {
+                            Q_UNUSED(reply)
+                            m_hasPushSubscription = false;
+                            subscribePushNotifications();
+                        });
+                    } else {
+                        updatePushNotifications();
+                    }
                 },
                 [=](QNetworkReply *reply) {
                     Q_UNUSED(reply);
@@ -425,6 +442,11 @@ void Account::updatePushNotifications()
 #ifdef HAVE_KUNIFIEDPUSH
     auto cfg = config();
 
+    // If push notifications are explicitly disabled (like if we have an account that does not have the scope) skip
+    if (!cfg->enablePushNotifications()) {
+        return;
+    }
+
     if (m_hasPushSubscription && !cfg->enableNotifications()) {
         unsubscribePushNotifications();
     } else if (!m_hasPushSubscription && cfg->enableNotifications()) {
@@ -508,3 +530,5 @@ QUrlQuery Account::buildNotificationFormData()
 
     return formdata;
 }
+
+#include "moc_account.cpp"
\ No newline at end of file
