@@ -3,14 +3,13 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "accountmanager.h"
-#include "account.h"
-#include "accountconfig.h"
-#include "config.h"
-#include "network/networkaccessmanagerfactory.h"
-#include "tokodon_debug.h"
-#include <qt6keychain/keychain.h>
 
-#include <utility>
+#include "account.h"
+#include "config.h"
+#include "networkaccessmanagerfactory.h"
+#include "tokodon_debug.h"
+
+#include <qt6keychain/keychain.h>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -496,6 +495,7 @@ void AccountManager::queueNotifications()
     static int accountsLeft = m_accounts.size();
 
     const auto checkIfDone = [this]() {
+        qInfo() << "Accounts left to check:" << accountsLeft;
         if (accountsLeft <= 0) {
             Q_EMIT finishedNotificationQueue();
         }
@@ -509,33 +509,45 @@ void AccountManager::queueNotifications()
         AccountConfig config(account->settingsGroupName());
 
         QUrlQuery urlQuery(uri);
-        urlQuery.addQueryItem(QStringLiteral("limit"), QString::number(1));
+        urlQuery.addQueryItem(QStringLiteral("limit"), QString::number(10));
         if (!config.lastPushNotification().isEmpty()) {
             urlQuery.addQueryItem(QStringLiteral("min_id"), config.lastPushNotification());
         }
         uri.setQuery(urlQuery);
 
-        account->get(uri, true, this, [this, account, checkIfDone](QNetworkReply *reply) {
-            const auto data = reply->readAll();
-            const auto doc = QJsonDocument::fromJson(data);
+        account->get(
+            uri,
+            true,
+            this,
+            [account, checkIfDone](QNetworkReply *reply) {
+                const auto data = reply->readAll();
+                const auto doc = QJsonDocument::fromJson(data);
+
+                if (!doc.isArray() || doc.array().isEmpty()) {
+                    accountsLeft--;
+                    checkIfDone();
+                    return;
+                }
+
+                for (auto notification : doc.array()) {
+                    if (notification.isObject()) {
+                        std::shared_ptr<Notification> n = std::make_shared<Notification>(account, notification.toObject());
+                        Q_EMIT account->notification(n);
+                    }
+                }
+
+                AccountConfig config(account->settingsGroupName());
+                config.setLastPushNotification(doc.array().first()["id"_L1].toString());
+                config.save();
 
-            if (!doc.isArray() || doc.array().isEmpty()) {
                 accountsLeft--;
                 checkIfDone();
-                return;
-            }
-
-            const auto obj = doc.array()[0].toObject();
-            std::shared_ptr<Notification> n = std::make_shared<Notification>(account, obj);
-
-            AccountConfig config(account->settingsGroupName());
-            config.setLastPushNotification(obj["id"_L1].toString());
-            config.save();
-
-            Q_EMIT account->notification(n);
-
-            accountsLeft--;
-            checkIfDone();
-        });
+            },
+            [checkIfDone](QNetworkReply *) {
+                accountsLeft--;
+                checkIfDone();
+            });
     }
 }
+
+#include "moc_accountmanager.cpp"
