@@ -2,10 +2,8 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "preferences.h"
-#include "identity.h"
-#include "utils/utils.h"
 
-#include <QHttpMultiPart>
+#include "utils.h"
 
 Preferences::Preferences(AbstractAccount *account)
     : QObject(account)
@@ -107,4 +105,6 @@ void Preferences::setPreferencesField(QString name, QString value)
     multiPart->append(preferencesPart);
 
     m_account->patch(m_account->apiUrl(QStringLiteral("/api/v1/accounts/update_credentials")), multiPart, true, this, [=](QNetworkReply *) {});
-}
\ No newline at end of file
+}
+
+#include "moc_preferences.cpp"
\ No newline at end of file
