@@ -3,11 +3,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "adminaccountinfo.h"
-#include "account/abstractaccount.h"
-#include "account/accountmanager.h"
+
 #include <KLocalizedString>
-#include <QDateTime>
-#include <QJsonObject>
+
+#include "abstractaccount.h"
+#include "accountmanager.h"
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -21,7 +21,7 @@ QString AdminAccountInfo::loginStatus() const
     if (m_suspended) {
         return i18nc("login status", "Suspended");
     } else if (m_silenced) {
-        return i18nc("login status", "Silenced");
+        return i18nc("login status", "Limited");
     } else if (m_sensitized) {
         return i18nc("login status", "Sensitized");
     } else if (m_disabled) {
@@ -60,6 +60,11 @@ Identity *AdminAccountInfo::userLevelIdentity() const
     return m_userLevelIdentity.get();
 }
 
+Identity *AdminAccountInfo::userLevelIdentityWithVanillaPointer() const
+{
+    return m_userLevelIdentityWithVanillaPointer;
+}
+
 bool AdminAccountInfo::suspended() const
 {
     return m_suspended;
@@ -229,3 +234,5 @@ void AdminAccountInfo::calculateRecentActivity(const QJsonArray &ipsArray)
     }
     m_lastActive = latestDateTime.toLocalTime();
 }
+
+#include "moc_adminaccountinfo.cpp"
\ No newline at end of file
