@@ -1,9 +1,8 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include "admin/emailinfo.h"
+#include "emailinfo.h"
 
-#include <QDateTime>
 #include <QJsonObject>
 
 using namespace Qt::Literals::StringLiterals;
@@ -53,3 +52,5 @@ EmailInfo EmailInfo::fromSourceData(const QJsonObject &doc)
 
     return info;
 }
+
+#include "moc_emailinfo.cpp"
\ No newline at end of file
