@@ -1,9 +1,10 @@
 // SPDX-FileCopyrightText: 2023 Rishi Kumar <rsi.dev17@gmail.com>
-// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include "admin/federationtoolmodel.h"
-#include "account/abstractaccount.h"
-#include "account/accountmanager.h"
+#include "federationtoolmodel.h"
+
+#include "abstractaccount.h"
+#include "accountmanager.h"
 
 #include <KLocalizedString>
 
@@ -282,3 +283,5 @@ void FederationToolModel::filltimeline(FederationAction action)
         setLoading(false);
     });
 }
+
+#include "moc_federationtoolmodel.cpp"
\ No newline at end of file
