@@ -3,13 +3,9 @@
 
 #include "conversationmodel.h"
 
-#include "account/abstractaccount.h"
-#include "account/accountmanager.h"
-#include "account/identity.h"
 #include <KLocalizedString>
+
 #include <QTextDocumentFragment>
-#include <algorithm>
-#include <qvariant.h>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -120,3 +116,5 @@ void ConversationModel::markAsRead(const QString &id)
         }
     });
 }
+
+#include "moc_conversationmodel.cpp"
\ No newline at end of file
