@@ -1,16 +1,8 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
-#include <QCommandLineParser>
-#include <QFontDatabase>
-#include <QNetworkProxy>
-#include <QNetworkProxyFactory>
-#include <QQmlApplicationEngine>
-#include <QQmlContext>
 #include <QQuickStyle>
-#include <QQuickWindow>
 #include <QtWebView>
-#include <clocale>
 
 #ifdef Q_OS_ANDROID
 #include "utils/androidutils.h"
@@ -19,15 +11,11 @@
 #include <QApplication>
 #endif
 
-#include <KAboutData>
 #ifdef HAVE_KDBUSADDONS
 #include <KDBusService>
 #include <KWindowSystem>
 #endif
-#include <KConfig>
-#include <KLocalizedContext>
 #include <KLocalizedString>
-#include <KWindowConfig>
 
 #ifdef HAVE_KUNIFIEDPUSH
 #include <kunifiedpush/connector.h>
@@ -42,6 +30,7 @@
 #include "config.h"
 #include "network/networkaccessmanagerfactory.h"
 #include "network/networkcontroller.h"
+#include "tokodon_debug.h"
 #include "utils/blurhashimageprovider.h"
 #include "utils/colorschemer.h"
 #include "utils/navigation.h"
@@ -58,11 +47,30 @@
 
 using namespace Qt::Literals::StringLiterals;
 
+void setupUnifiedPush()
+{
+#ifdef HAVE_KUNIFIEDPUSH
+    auto connector = new KUnifiedPush::Connector(QStringLiteral("org.kde.tokodon"));
+    QObject::connect(connector, &KUnifiedPush::Connector::endpointChanged, [=](const auto &endpoint) {
+        NetworkController::instance().endpoint = endpoint;
+    });
+
+    NetworkController::instance().endpoint = connector->endpoint();
+
+    connector->registerClient(i18n("Receiving push notifications"));
+#endif
+}
+
 #ifdef Q_OS_ANDROID
 Q_DECL_EXPORT
 #endif
 int main(int argc, char *argv[])
 {
+    // TODO: temporary qt6 android fix
+#ifdef Q_OS_ANDROID
+    qputenv("QT_MEDIA_BACKEND", "ANDROID");
+#endif
+
     QNetworkProxyFactory::setUseSystemConfiguration(true);
     QtWebView::initialize();
 
@@ -73,7 +81,8 @@ int main(int argc, char *argv[])
             AndroidUtils::instance().checkPendingIntents();
         }
     });
-    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
+    // TODO: restore once qqc2-breeze-style works again
+    // QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     QApplication app(argc, argv);
     // Default to org.kde.desktop style unless the user forces another style
@@ -128,7 +137,7 @@ int main(int argc, char *argv[])
     shareOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
     parser.addOption(shareOption);
 
-    QCommandLineOption notifyOption(QStringLiteral("notify"), i18n("Internal usage only."));
+    QCommandLineOption notifyOption(QStringLiteral("dbus-activated"), i18n("Internal usage only."));
     notifyOption.setFlags(QCommandLineOption::Flag::HiddenFromHelp);
     parser.addOption(notifyOption);
 
@@ -136,10 +145,6 @@ int main(int argc, char *argv[])
     parser.process(app);
     about.processCommandLine(&parser);
 
-    // Qt sets the locale in the QGuiApplication constructor, but libmpv
-    // requires the LC_NUMERIC category to be set to "C", so change it back.
-    setlocale(LC_NUMERIC, "C");
-
     auto &colorSchemer = ColorSchemer::instance();
     auto config = Config::self();
     if (!config->colorScheme().isEmpty()) {
@@ -156,20 +161,30 @@ int main(int argc, char *argv[])
 
 #ifdef HAVE_KUNIFIEDPUSH
     if (parser.isSet(notifyOption)) {
-        // TODO: timeout
+        qInfo(TOKODON_LOG) << "Beginning to check for notifications...";
+
+#ifdef HAVE_KDBUSADDONS
+        // We want to be replaceable by the main client
+        KDBusService service(KDBusService::Replace);
+#endif
+
+        setupUnifiedPush();
 
         // create the lazy instance
-        Q_UNUSED(AccountManager::instance());
+        AccountManager::instance().loadFromSettings();
 
         QObject::connect(&AccountManager::instance(), &AccountManager::accountsReady, [] {
+            qInfo(TOKODON_LOG) << "Accounts have finished loading. Checking notification queue...";
             // queue notification
             AccountManager::instance().queueNotifications();
-            qDebug() << "queueing";
         });
 
         QObject::connect(&AccountManager::instance(), &AccountManager::finishedNotificationQueue, [] {
-            // begin timer
-            // QCoreApplication::quit();
+            // Sleep for a bit so the notifications stay open
+            // TODO: make this depend on all of the knotifications closing
+            QTimer *timer = new QTimer();
+            timer->setInterval(1000);
+            timer->connect(timer, &QTimer::timeout, qApp, &QCoreApplication::quit);
         });
 
         return QCoreApplication::exec();
@@ -180,16 +195,7 @@ int main(int argc, char *argv[])
     KDBusService service(KDBusService::Unique);
 #endif
 
-#ifdef HAVE_KUNIFIEDPUSH
-    auto connector = new KUnifiedPush::Connector(service.serviceName());
-    QObject::connect(connector, &KUnifiedPush::Connector::endpointChanged, [=](const auto &endpoint) {
-        NetworkController::instance().endpoint = endpoint;
-    });
-
-    NetworkController::instance().endpoint = connector->endpoint();
-
-    connector->registerClient(i18n("Receiving push notifications"));
-#endif
+    setupUnifiedPush();
 
 #ifdef HAVE_KDBUSADDONS
     QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine](const QStringList &arguments, const QString & /*workingDirectory*/) {
