@@ -3,15 +3,11 @@
 
 #include "networkcontroller.h"
 
-#include "account/abstractaccount.h"
-#include "account/accountmanager.h"
+#include "abstractaccount.h"
+#include "accountmanager.h"
 #include "config.h"
 #include "tokodon_http_debug.h"
 
-#include <QNetworkProxy>
-#include <QUrlQuery>
-#include <utility>
-
 using namespace Qt::Literals::StringLiterals;
 
 NetworkController::NetworkController(QObject *parent)
@@ -111,8 +107,21 @@ void NetworkController::openLink()
         m_requestedLink.setUserInfo(QString());
     }
 
+    const QUrl instanceUrl(account->instanceUri());
+
+    // TODO: this assumes the post id is in the last path segment
+    // Is this always true? Maybe there's some way to query it.
+    if (instanceUrl.host() == m_requestedLink.host()) {
+        QString path = m_requestedLink.path();
+        path.remove(0, path.lastIndexOf(QLatin1Char('/')) + 1);
+
+        Q_EMIT NetworkController::instance().openPost(path);
+        return;
+    }
+
     requestRemoteObject(account, m_requestedLink.toString(), [=](QNetworkReply *reply) {
         const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
+
         const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
         const auto accounts = searchResult[QStringLiteral("accounts")].toArray();
 
@@ -155,3 +164,5 @@ void NetworkController::requestRemoteObject(AbstractAccount *account, const QStr
     });
     account->get(url, true, &AccountManager::instance(), std::move(callback));
 }
+
+#include "moc_networkcontroller.cpp"
\ No newline at end of file
