@@ -2,8 +2,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "tagstimelinemodel.h"
-#include "account/abstractaccount.h"
-#include <QUrlQuery>
 
 TagsTimelineModel::TagsTimelineModel(QObject *parent)
     : TimelineModel(parent)
@@ -69,3 +67,13 @@ void TagsTimelineModel::fillTimeline(const QString &fromId)
         },
         handleError);
 }
+
+void TagsTimelineModel::reset()
+{
+    beginResetModel();
+    qDeleteAll(m_timeline);
+    m_timeline.clear();
+    endResetModel();
+}
+
+#include "moc_tagstimelinemodel.cpp"
