@@ -4,8 +4,6 @@
 
 #pragma once
 
-#include <QtQml/qqmlregistration.h>
-
 #include "timelinemodel.h"
 
 /// Model for displaying and organizing post threads
@@ -38,6 +36,8 @@ public:
     /// Can be used to find where exactly to position the view
     Q_INVOKABLE int getRootIndex() const;
 
+    void reset() override;
+
 Q_SIGNALS:
     void postIdChanged();
 
