@@ -3,14 +3,6 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "timelinemodel.h"
-#include "account/abstractaccount.h"
-#include "accountmodel.h"
-#include "poll.h"
-#include <KLocalizedString>
-#include <QJsonArray>
-#include <QJsonObject>
-#include <QtMath>
-#include <algorithm>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -33,14 +25,20 @@ void TimelineModel::init()
         if (m_account == account) {
             qDebug() << "Invalidating account" << account;
 
-            beginResetModel();
-            m_timeline.clear();
-            endResetModel();
-
+            reset();
             fillTimeline();
         }
     });
 
+    connect(this, &TimelineModel::showBoostsChanged, this, [this] {
+        reset();
+        fillTimeline();
+    });
+    connect(this, &TimelineModel::showRepliesChanged, this, [this] {
+        reset();
+        fillTimeline();
+    });
+
     connect(m_manager, &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
         if (m_account == account) {
             return;
@@ -54,10 +52,7 @@ void TimelineModel::init()
 
         connect(m_account, &AbstractAccount::streamingEvent, this, &TimelineModel::handleEvent);
 
-        beginResetModel();
-        qDeleteAll(m_timeline);
-        m_timeline.clear();
-        endResetModel();
+        reset();
 
         setLoading(false);
 
@@ -95,7 +90,13 @@ void TimelineModel::fetchedTimeline(const QByteArray &data, bool alwaysAppendToE
 
     posts.erase(std::remove_if(posts.begin(),
                                posts.end(),
-                               [](Post *post) {
+                               [this](Post *post) {
+                                   if (!m_showBoosts && post->boostIdentity()) {
+                                       return true;
+                                   }
+                                   if (!m_showReplies && !post->inReplyTo().isEmpty()) {
+                                       return true;
+                                   }
                                    return post == nullptr;
                                }),
                 posts.end());
@@ -276,4 +277,6 @@ void TimelineModel::handleEvent(AbstractAccount::StreamingEventType eventType, c
             i++;
         }
     }
-}
\ No newline at end of file
+}
+
+#include "moc_timelinemodel.cpp"
\ No newline at end of file
