@@ -1,11 +1,10 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carlschwan@kde.org>
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include <KColorSchemeManager>
-#include <QAbstractItemModel>
-
 #include "colorschemer.h"
 
+#include <KColorSchemeManager>
+
 ColorSchemer::ColorSchemer(QObject *parent)
     : QObject(parent)
     , c(new KColorSchemeManager(this))
@@ -46,3 +45,5 @@ QString ColorSchemer::nameForIndex(int index) const
 {
     return c->model()->data(c->model()->index(index, 0), Qt::DisplayRole).toString();
 }
+
+#include "moc_colorschemer.cpp"
\ No newline at end of file
